@@ -52,8 +52,8 @@ def calculate_maxi_min_rjl(data):
 
         return {'max_rongjilv':max_rongjilv, 'min_rongjilv':min_rongjilv}
     except Exception as e:
-        print(e)
-        logger.debug(f'{data}出现问题')
+        logger.debug(f'解析失败数据为：{data}')
+        return data
 
 def calculate_maxi_min_lhl(data):
     try:
@@ -96,9 +96,8 @@ def calculate_maxi_min_lhl(data):
 
         return {'max_lhl':max_lhl, 'min_lhl':min_lhl}
     except Exception as e:
-        print(e)
-        print(data)
-        logger.debug(f'{data}出现问题')
+        logger.debug(f'解析失败数据为：{data}')
+        return data
 def calculate_maxi_min_jzmd(data):
     try:
         lst = re.findall(r'[0-9|.]+%', data)
@@ -140,9 +139,9 @@ def calculate_maxi_min_jzmd(data):
 
         return {'max_jzmd':max_jzmd, 'min_jzmd':min_jzmd}
     except Exception as e:
-        print(e)
-        print(data)
-        logger.debug(f'{data}出现问题')
+        logger.debug(f'解析失败数据为：{data}')
+        return data
+
 
 def read_csv():
     data_list = list()
@@ -159,5 +158,5 @@ def read_csv():
 
 
 if __name__ == '__main__':
-    # print(calculate_maxi_min_lhl('20%'))
-    read_csv()
+    print(calculate_maxi_min_rjl('1.5-2.0'))
+
